<?php

include_once('library/bones.php');

// Theme Options

function aboutme_admin_init() {
    register_setting( 'aboutme-theme-options', 'aboutme-theme-options' );
    add_settings_section( 'section_colors', 'Color Settings', 'aboutme_section_colors', 'aboutme-theme-options' );
    add_settings_field( 'logo_color', 'Logo/Heading Text Color', 'aboutme_logo_color', 'aboutme-theme-options', 'section_colors' );
	add_settings_field( 'desc_color', 'Site Description Text Color', 'aboutme_description_color', 'aboutme-theme-options', 'section_colors' );
	add_settings_field( 'link_color', 'Custom Home Page Link Color', 'aboutme_link_color', 'aboutme-theme-options', 'section_colors' );
	add_settings_field( 'text_color', 'Custom Home Page Text Color', 'aboutme_text_color', 'aboutme-theme-options', 'section_colors' );
	add_settings_field( 'heading_color', 'Archives/Categories Heading Color', 'aboutme_heading_color', 'aboutme-theme-options', 'section_colors' );
	add_settings_field( 'link_all', 'All Pages Link Color', 'aboutme_link_all', 'aboutme-theme-options', 'section_colors' );
	
	add_settings_section( 'section_icons', 'Social Bookmarks', 'aboutme_section_icons', 'aboutme-theme-options' );
	add_settings_field( 'sb_fb', 'Add Facebook', 'aboutme_sb_fb', 'aboutme-theme-options', 'section_icons' );
	add_settings_field( 'sb_tw', 'Add Twitter', 'aboutme_sb_tw', 'aboutme-theme-options', 'section_icons' );
	add_settings_field( 'sb_fl', 'Add Flickr', 'aboutme_sb_fl', 'aboutme-theme-options', 'section_icons' );
	add_settings_field( 'sb_li', 'Add LinkedIn', 'aboutme_sb_li', 'aboutme-theme-options', 'section_icons' );
	add_settings_field( 'sb_em', 'Add Email or Contact Page', 'aboutme_sb_em', 'aboutme-theme-options', 'section_icons' );

}
add_action( 'admin_init', 'aboutme_admin_init' );

function aboutme_admin_menu() {
    $page = add_theme_page( 'Theme Options', 'Theme Options', 'edit_theme_options', 'aboutme-theme-options', 'aboutme_theme_options' );
    add_action( 'admin_print_styles-' . $page, 'aboutme_admin_scripts' );
}
add_action( 'admin_menu', 'aboutme_admin_menu' );

function aboutme_admin_scripts() {
    wp_enqueue_style( 'farbtastic' );
    wp_enqueue_script( 'farbtastic' );
    wp_enqueue_script( 'aboutme-theme-options', get_template_directory_uri() . '/library/js/theme-options.js', array( 'farbtastic', 'jquery' ) );
}

function aboutme_theme_options() {
    ?>
    <div class="wrap">
        <div id="icon-themes" class="icon32" ><br></div>
        <h2>About Me Theme Options</h2>

        <form method="post" action="options.php">
            <?php wp_nonce_field( 'update-options' ); ?>
            <?php settings_fields( 'aboutme-theme-options' ); ?>
            <?php do_settings_sections( 'aboutme-theme-options' ); ?>
            <p class="submit">
                <input name="Submit" type="submit" class="button-primary" value="Save Changes" />
            </p >
        </form>
    </div>
    <?php
}

function aboutme_section_colors() {
    _e( '<p>You can input color names like "blue", "aqua", "darkred", "silver", etc., just make sure that they are valid HTML color names. You can also enter their hexadecimal values (e.g. #ff0033). Or better yet, just use the color  picker by pressing the "Select Color" button. Leaving the fields blank will revert the colors the their default values.</p>', 'about-me' );
}

function aboutme_logo_color() {
	
    $options = get_option( 'aboutme-theme-options' );
	
	if ($options['logo_color'] == "") {
		$options['logo_color'] = "#e4ff00";
	}
    ?>
    <div class="color-picker" style="position: relative;">
        <input type="text" name="aboutme-theme-options[logo_color]" id="logo_color" value="<?php echo esc_attr( $options['logo_color'] ); ?>" />
        <input type='button' class='pickcolor button-secondary' value='Select Color'>
		<div id='colorpicker' style='z-index: 100; background:#eee; border:1px solid #ccc; position:absolute; display:none;'></div>
    </div>
    <?php
}

function aboutme_description_color() {
	
    $options = get_option( 'aboutme-theme-options' );
	
	if ($options['desc_color'] == "") {
		$options['desc_color'] = "#ffffff";
	}
    ?>
    <div class="color-picker" style="position: relative;">
        <input type="text" name="aboutme-theme-options[desc_color]" id="desc_color" value="<?php echo esc_attr( $options['desc_color'] ); ?>" />
        <input type='button' class='pickcolor button-secondary' value='Select Color'>
		<div id='colorpicker2' style='z-index: 100; background:#eee; border:1px solid #ccc; position:absolute; display:none;'></div>
    </div>
    <?php
}

function aboutme_link_color() {
	
    $options = get_option( 'aboutme-theme-options' );
	
	if ($options['link_color'] == "") {
		$options['link_color'] = "#e4ff00";
	}
    ?>
    <div class="color-picker" style="position: relative;">
        <input type="text" name="aboutme-theme-options[link_color]" id="link_color" value="<?php echo esc_attr( $options['link_color'] ); ?>" />
        <input type='button' class='pickcolor button-secondary' value='Select Color'>
		<div id='colorpicker3' style='z-index: 100; background:#eee; border:1px solid #ccc; position:absolute; display:none;'></div>
    </div>
    <?php
}

function aboutme_link_all() {
	
    $options = get_option( 'aboutme-theme-options' );
	
	if ($options['link_all'] == "") {
		$options['link_all'] = "#3366cc";
	}
    ?>
    <div class="color-picker" style="position: relative;">
        <input type="text" name="aboutme-theme-options[link_all]" id="link_all" value="<?php echo esc_attr( $options['link_all'] ); ?>" />
        <input type='button' class='pickcolor button-secondary' value='Select Color'>
		<div id='colorpicker4' style='z-index: 100; background:#eee; border:1px solid #ccc; position:absolute; display:none;'></div>
    </div>
    <?php
}

function aboutme_heading_color() {
	
    $options = get_option( 'aboutme-theme-options' );
	
	if ($options['heading_color'] == "") {
		$options['heading_color'] = "#ffffff";
	}
    ?>
    <div class="color-picker" style="position: relative;">
        <input type="text" name="aboutme-theme-options[heading_color]" id="heading_color" value="<?php echo esc_attr( $options['heading_color'] ); ?>" />
        <input type='button' class='pickcolor button-secondary' value='Select Color'>
		<div id='colorpicker5' style='z-index: 100; background:#eee; border:1px solid #ccc; position:absolute; display:none;'></div>
    </div>
    <?php
}

function aboutme_text_color() {
	
    $options = get_option( 'aboutme-theme-options' );
	
	if ($options['text_color'] == "") {
		$options['text_color'] = "#ffffff";
	}
    ?>
    <div class="color-picker" style="position: relative;">
        <input type="text" name="aboutme-theme-options[text_color]" id="text_color" value="<?php echo esc_attr( $options['text_color'] ); ?>" />
        <input type='button' class='pickcolor button-secondary' value='Select Color'>
		<div id='colorpicker5' style='z-index: 100; background:#eee; border:1px solid #ccc; position:absolute; display:none;'></div>
    </div>
    <?php
}

function aboutme_section_icons() {
    _e( '<p>You can insert the url\'s for the following social networking tools and their respective icons will be shown on your custom homepage.</p>', 'about-me' );
}

function aboutme_sb_tw() {
	
    $options = get_option( 'aboutme-theme-options' );
	
    ?>

     <input type="text" name="aboutme-theme-options[sb_tw]" id="sb_tw" value="<?php echo esc_attr( $options['sb_tw'] ); ?>" />

    <?php
}

function aboutme_sb_fb() {
	
    $options = get_option( 'aboutme-theme-options' );
	
    ?>

     <input type="text" name="aboutme-theme-options[sb_fb]" id="sb_fb" value="<?php echo esc_attr( $options['sb_fb'] ); ?>" />

    <?php
}

function aboutme_sb_fl() {
	
    $options = get_option( 'aboutme-theme-options' );
	
    ?>

     <input type="text" name="aboutme-theme-options[sb_fl]" id="sb_fl" value="<?php echo esc_attr( $options['sb_fl'] ); ?>" />

    <?php
}

function aboutme_sb_li() {
	
    $options = get_option( 'aboutme-theme-options' );
	
    ?>

     <input type="text" name="aboutme-theme-options[sb_li]" id="sb_li" value="<?php echo esc_attr( $options['sb_li'] ); ?>" />

    <?php
}

function aboutme_sb_em() {
	
    $options = get_option( 'aboutme-theme-options' );
	
    ?>

     <input type="text" name="aboutme-theme-options[sb_em]" id="sb_em" value="<?php echo esc_attr( $options['sb_em'] ); ?>" />

    <?php
}



function aboutme_wp_head() {
    $options = get_option( 'aboutme-theme-options' );
	$link_all = $options['link_all'];
    $logo_color = $options['logo_color']; 
	$desc_color = $options['desc_color'];
	$link_color = $options['link_color'];
	$text_color = $options['text_color'];
	$heading_color = $options['heading_color'];
	?>
    <style> 
		a, a:visited { color: <?php echo $link_all ?> }
		#logo a { color: <?php echo $logo_color ?> } 
		#site-description { color: <?php echo $desc_color ?> }
		#custom-home-content article[id*=post-] a { color: <?php echo $link_color ?> }
		#custom-home-content article[id*=post-] { color: <?php echo $text_color ?> }
		.archive_title { color: <?php echo $heading_color ?>; }
		.wp-prev-next a, .widget a, .attribution a { color:#fff; }
    </style>
    <?php
}
add_action( 'wp_head', 'aboutme_wp_head' );


//Set the content width based on the theme's design and stylesheet.

if ( ! isset( $content_width ) )
	$content_width = 550;

// Adding Translation
load_theme_textdomain( 'about-me', TEMPLATEPATH.'/lang' );
 
$locale = get_locale();
$locale_file = TEMPLATEPATH."/lang/$locale.php";
if ( is_readable($locale_file) )
    require_once($locale_file);




// Sidebars & Widgetizes Areas
function aboutme_register_sidebars() {
    register_sidebar(array(
    	'id' => 'sidebar1',
    	'name' => 'Sidebar 1',
    	'description' => 'The first (primary) sidebar.',
    	'before_widget' => '<div id="%1$s" class="widget %2$s">',
    	'after_widget' => '</div>',
    	'before_title' => '<h4 class="widgettitle">',
    	'after_title' => '</h4>',
    ));
    
    /* 
    to add more sidebars or widgetized areas, just copy
    and edit the above sidebar code. In order to call 
    your new sidebar just use the following code:
    
    Just change the name to whatever your new
    sidebar's id is.
    */
}

// adding sidebars to Wordpress
add_action( 'widgets_init', 'aboutme_register_sidebars' );
		
// Comment Layout
function aboutme_comments($comment, $args, $depth) {
   $GLOBALS['comment'] = $comment; ?>
	<li <?php comment_class(); ?>>
		<article id="comment-<?php comment_ID(); ?>">
			<header class="comment-author vcard">
				<?php echo get_avatar($comment,$size='45',$default='<path_to_url>' ); ?>
				<?php printf(__('<cite class="fn">%s</cite>', 'about-me'), get_comment_author_link()) ?>
				<time><a href="<?php echo htmlspecialchars( get_comment_link( $comment->comment_ID ) ) ?>"><?php printf(__('%1$s', 'about-me'), get_comment_date(),  get_comment_time()) ?></a></time>
				<?php edit_comment_link(__('(Edit)', 'about-me'),'  ','') ?>
			</header>

			<?php if ($comment->comment_approved == '0') : ?>
       			<div class="help">
          			<p><?php _e('Your comment is awaiting moderation.', 'about-me') ?></p>
          		</div>
          		
			<?php endif; ?>
			
			<section class="comment_content clearfix">
				<?php comment_text() ?>
			</section>

			<?php comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))) ?>
			
		</article>
    <!-- </li> is added by wordpress automatically -->
<?php
}


remove_custom_image_header();


function aboutme_rel_tag( $text ) {
	$text = str_replace('rel="category tag"', 'rel="tag"', $text);
	return $text;
}
add_filter( 'the_category', 'aboutme_rel_tag' );


function aboutme_scripts_jquery() {
    wp_enqueue_script('jquery');
}    
add_action('wp_enqueue_scripts', 'aboutme_scripts_jquery');


function aboutme_scripts_modernizr() {
    wp_register_script( 'modernizr', get_template_directory_uri() . '/library/js/modernizr-2.0.min.js');
    wp_enqueue_script( 'modernizr' );
}    
add_action('wp_enqueue_scripts', 'aboutme_scripts_modernizr');


function aboutme_scripts_custom() {
    wp_register_script( 'custom-scripts', get_template_directory_uri() . '/library/js/scripts.js');
    wp_enqueue_script( 'custom-scripts' );
}    
add_action('wp_enqueue_scripts', 'aboutme_scripts_custom');



?>